"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signupRequestParser = exports.passwordEntropyParser = void 0;
const zod_1 = require("zod");
const email_1 = require("../../../common/parsers/email");
const entropy_1 = require("../../../utils/string/entropy");
const ENTROPY_THRESHOLD = 50; // pretty weak
exports.passwordEntropyParser = zod_1.z.string().superRefine((s, ctx) => {
    const en = (0, entropy_1.entropy)(s);
    if (en >= ENTROPY_THRESHOLD)
        return;
    ctx.addIssue({
        code: zod_1.z.ZodIssueCode.custom,
        params: {
            entropy: en,
            required: ENTROPY_THRESHOLD,
            code: 'entropy',
        },
        message: `Password entropy is too low (${en}). Minimum entropy is ${ENTROPY_THRESHOLD}`,
    });
});
const passwordParser = zod_1.z.string().min(8).and(exports.passwordEntropyParser);
exports.signupRequestParser = zod_1.z.object({
    email: email_1.emailParser,
    password: passwordParser,
});
