"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stripePriceIdParser = exports.stripeSubscriptionIdParser = exports.stripePaymentIntentIdParser = exports.stripeInvoiceIdParser = exports.stripeCustomerIdParser = exports.stripePaymentMethodIdParser = exports.stripeProductIdParser = void 0;
const zod_1 = require("zod");
const constants_1 = require("./constants");
const parsers_1 = require("../utils/parsers");
const price_utils_1 = require("./price.utils");
const utils_1 = require("../channel/utils");
exports.stripeProductIdParser = zod_1.z
    .string()
    .startsWith(constants_1.STRIPE_PRODUCT_PREFIX)
    .length(19)
    .transform((0, parsers_1.cast)());
exports.stripePaymentMethodIdParser = zod_1.z
    .string()
    .startsWith(constants_1.STRIPE_PAYMENT_METHOD_PREFIX)
    .transform((0, parsers_1.cast)());
exports.stripeCustomerIdParser = zod_1.z.string().startsWith(constants_1.STRIPE_CUSTOMER_PREFIX).transform((0, parsers_1.cast)());
exports.stripeInvoiceIdParser = zod_1.z.string().startsWith(constants_1.STRIPE_INVOICE_PREFIX).transform((0, parsers_1.cast)());
exports.stripePaymentIntentIdParser = zod_1.z
    .string()
    .startsWith(constants_1.STRIPE_PAYMENT_INTENT_PREFIX)
    .transform((0, parsers_1.cast)());
exports.stripeSubscriptionIdParser = zod_1.z
    .string()
    .startsWith(constants_1.STRIPE_SUBSCRIPTION_PREFIX)
    .transform((0, parsers_1.cast)());
exports.stripePriceIdParser = zod_1.z
    .string()
    .startsWith(constants_1.STRIPE_PRICE_PREFIX)
    .superRefine((s, ctx) => {
    const channelId = (0, price_utils_1.getChannelIdFromPriceId)(s);
    if (!channelId || !(0, utils_1.isChannelId)(channelId)) {
        ctx.addIssue({
            code: 'custom',
            message: "Can't find a valid channel id in provided price id",
        });
    }
})
    .transform((0, parsers_1.cast)());
