import { z, ZodType } from 'zod';

import { isMixspaceId } from './id.utils';
import { firestoreListParamsParser } from '../common/parsers/queryParams';
import { MIXSPACE_ID_PARAM_NAME } from './route.constants';
import { Mixspace } from './types';
import { MixspaceId } from './id.types';

export const mixspaceListQueryParser = firestoreListParamsParser;
export const mixspaceListResultParser = z.array(z.any()).transform((a) => a as Mixspace[]);

export const mixspaceIdParser = z.string().refine(isMixspaceId);

export const mixspaceGetOneParamsParser = z.object({
  [MIXSPACE_ID_PARAM_NAME]: mixspaceIdParser,
});

export const mixspaceGetOneResultParser = z.any(/* stub */).transform((o) => o as Mixspace);

export const mixspaceDeleteParamsParser = mixspaceGetOneParamsParser;

export const mixspaceAdminParser = z.string(); // TODO make sense of what we store here

export const makeMixspaceAdminsParser = <T extends string, P extends z.ZodType<T>>(p: P) => z.array(p);

export const makeMixspaceAdminsTraitParser = <T1, T extends ZodType<T1>>(a: T) =>
  z.object({
    admins: a,
  });

export const mixspaceAdminsTraitParser = makeMixspaceAdminsTraitParser(makeMixspaceAdminsParser(mixspaceAdminParser));

export const mixspaceCreateInputParser = mixspaceAdminsTraitParser.merge(
  z.object({
    accessThreshold: z.number().default(0), //default open access
    image: z
      .string()
      .url()
      .refine((s) => s.length > 0, {
        message: 'Field Required',
      }),
    items: z.array(
      z.object({
        edge: z.boolean().default(false),
        uuid: z.string(), //type for all uuid types
        x: z.number(),
        y: z.number(),
      })
    ),
    paymentWeights: z.object({}),
    reward: z.object({
      active: z.boolean().default(false), //we could maybe derive this bool from a combination of assets.length and !!(price > 0) below
      assets: z.array(z.string()),
      price: z.number().default(0),
    }),
    title: z.string().refine((s) => s.length > 0, {
      message: 'Field Required',
    }),
  })
);
export const mixspaceCreateResponseParser = z.any(/*stub*/).transform((a) => a as MixspaceId);

export const mixspaceUpdateInputParser = mixspaceCreateInputParser.partial();
export const mixspaceUpdateParamsParser = mixspaceGetOneParamsParser;
