import { z } from 'zod';
import {
  STRIPE_CUSTOMER_PREFIX,
  STRIPE_INVOICE_PREFIX,
  STRIPE_PAYMENT_INTENT_PREFIX,
  STRIPE_PAYMENT_METHOD_PREFIX,
  STRIPE_PRICE_PREFIX,
  STRIPE_PRODUCT_PREFIX,
  STRIPE_SUBSCRIPTION_PREFIX,
} from './constants';
import type {
  StripeCustomerId,
  StripeInvoiceId,
  StripePaymentIntentId,
  StripePaymentMethodId,
  StripePriceId,
  StripeProductId,
  StripeSubscriptionId,
} from './types';
import { cast } from '../utils/parsers';
import { getChannelIdFromPriceId } from './price.utils';
import { isChannelId } from '../channel/utils';

export const stripeProductIdParser = z
  .string()
  .startsWith(STRIPE_PRODUCT_PREFIX)
  .length(19)
  .transform(cast<StripeProductId>());
export const stripePaymentMethodIdParser = z
  .string()
  .startsWith(STRIPE_PAYMENT_METHOD_PREFIX)
  .transform(cast<StripePaymentMethodId>());
export const stripeCustomerIdParser = z.string().startsWith(STRIPE_CUSTOMER_PREFIX).transform(cast<StripeCustomerId>());
export const stripeInvoiceIdParser = z.string().startsWith(STRIPE_INVOICE_PREFIX).transform(cast<StripeInvoiceId>());
export const stripePaymentIntentIdParser = z
  .string()
  .startsWith(STRIPE_PAYMENT_INTENT_PREFIX)
  .transform(cast<StripePaymentIntentId>());
export const stripeSubscriptionIdParser = z
  .string()
  .startsWith(STRIPE_SUBSCRIPTION_PREFIX)
  .transform(cast<StripeSubscriptionId>());
export const stripePriceIdParser = z
  .string()
  .startsWith(STRIPE_PRICE_PREFIX)
  .superRefine((s, ctx) => {
    const channelId = getChannelIdFromPriceId(s);
    if (!channelId || !isChannelId(channelId)) {
      ctx.addIssue({
        code: 'custom',
        message: "Can't find a valid channel id in provided price id",
      });
    }
  })
  .transform(cast<StripePriceId>());
